==> customer-link-project-api-0.0.58-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/SelfPushResultRes.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

import cn.com.duiba.customer.link.project.api.remoteservice.app89420.dto.CommonResDTO;

public class SelfPushResultRes extends CommonResDTO {
    /**
     * 口味王订单号
     */
    private String orderId;

    /**
     * 兑吧订单号
     */
    private String orderNo;
    /**
     * 红包发放时间
     * 发放成功为微信返回的发放红包的时间戳，发放失败为默认值0
     */
    private String payTime;
    /**
     * 微信返回的红包发放结果
     */
    private String payResult;
    /**
     * 红包金额
     */
    private Integer amount;

    /**
     * 用户id
     */
    private String userId;
    /**
     * 1:代表发放成功；2：代表发放失败。
     */
    private String status;
    /**
     * 响应代码
     */
    private String resCode;

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getPayTime() {
        return payTime;
    }

    public void setPayTime(String payTime) {
        this.payTime = payTime;
    }

    public String getPayResult() {
        return payResult;
    }

    public void setPayResult(String payResult) {
        this.payResult = payResult;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getResCode() {
        return resCode;
    }

    public void setResCode(String resCode) {
        this.resCode = resCode;
    }
}

==> customer-link-project-api-1.1.30-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/SelfPushResultRes.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

import cn.com.duiba.customer.link.project.api.remoteservice.app89420.dto.CommonResDTO;

public class SelfPushResultRes extends CommonResDTO {
    /**
     * 错误码（200-请求成功；40002-订单不存在；40003-订单已支付成功 无需补领；40004-订单不为失败状态,无法补领）
     */
    private String errorCode;

    /**
     * 错误信息
     */
    private String errorMessage;

    /******* 后面的字段自2025年3月25日后弃用 *******/

    /**
     * 口味王订单号
     */
    private String orderId;

    /**
     * 兑吧订单号
     */
    private String orderNo;
    /**
     * 红包发放时间
     * 发放成功为微信返回的发放红包的时间戳，发放失败为默认值0
     */
    private String payTime;
    /**
     * 微信返回的红包发放结果
     */
    private String payResult;
    /**
     * 红包金额
     */
    private Integer amount;

    /**
     * 用户id
     */
    private String userId;
    /**
     * 订单状态（SUCCESS：支付成功；FAIL：支付失败；PENDING：支付中）
     */
    private String status;
    /**
     * 响应代码
     */
    private String resCode;

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getPayTime() {
        return payTime;
    }

    public void setPayTime(String payTime) {
        this.payTime = payTime;
    }

    public String getPayResult() {
        return payResult;
    }

    public void setPayResult(String payResult) {
        this.payResult = payResult;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getResCode() {
        return resCode;
    }

    public void setResCode(String resCode) {
        this.resCode = resCode;
    }
}
